@Version 2, March, 2009.
These routines can be used by and distributed for non-profit academic purposes
without any royalty except that the users must cite:
Perron and Yabu (2009): "Estimating Deterministic Trends with an Integrated or
Stationary Noise Component," forthcoming in Journal of Econometrics.
for any other commercial use and/or comments,  please contact 
Pierre Perron at perron at bu.edu.
Even though we tried to make this program error-free we cannot be held
responsible for any consequences that could result from remaining errors.
Copyright, Pierre Perron and Tomoyoshi Yabu (2009).@


new;
format /ld 6,4;

#include trcode.src; @set the path to where you store the file trcode.src@

output file = results.out reset; @select your output file@

load yyy[170,1]=LUS.dat; @read your data (log of US GDP in this case)@

dep=yyy[.,1];  @set up the data, dep is the dependent variable@

T=rows(dep);         @number of sample@

kmax=int(12*(T/100)^(1/4)); @maximum number of lag length@

a_type = 2; @type=1; supper-efficient estimator is based on the median unbiased estimator@
          @type=2; supper-efficient estimator is based on the upper-biased estimator@

/***********************************/
/*Do not change the following code */
/***********************************/
{p} = mic1(dep,1,0,kmax,0);
{ahat,am,au} = RF(dep,p);
{tstat1,stdb1,b1,ams} = QFGLS(dep,p,am);
{tstat2,stdb2,b2,aus} = QFGLS(dep,p,au);

print "************************************************";
print "The model considered is the following:";
print "     y{t} = b0 + b1*t + u{t}";
print "where u{t} = a*u{t-1} + A(L)(u{t-1}-u{t-2}) + e{t}";

if a_type==1;
print "";
print "   y{t} = " b1[1] "+" b1[2] "*t + u{t}";
print "         "     "(" stdb1[1] ")"  "(" stdb1[2] ")";
print "";
print "where standard errors are given in parentheses and"; 
print "lag length is chosen as k =" p "by Modified AIC.";
print "";
print "  weighted symmetric least-squares esimtator: " ahat; 
print "  median-unbiased esimtator(a_MU):            " am; 
print "  supper-efficient estimate(based on a_MU):   " ams; 
print "";
print "  t-stat:" tstat1; 
print "";
print "  90% confidence interval for b1";
print "      " b1[2]-1.65*stdb1[2]  "<"  b1[2]  "<"   b1[2]+1.65*stdb1[2];
print "  95% confidence interval for b1";
print "      " b1[2]-1.96*stdb1[2]  "<"  b1[2]  "<"   b1[2]+1.96*stdb1[2];
print "  99% confidence interval for b1";
print "      " b1[2]-2.57*stdb1[2]  "<"  b1[2]  "<"   b1[2]+2.57*stdb1[2];

elseif a_type==2;
print "";
print "   y{t} = " b2[1] "+" b2[2] "*t + u{t}";
print "         "     "(" stdb2[1] ")"  "(" stdb2[2] ")";
print "";
print "where standard errors are given in parentheses and"; 
print "lag length is chosen as k =" p "by Modified AIC.";
print "";
print "  weighted symmetric least-squares esimtator: " ahat; 
print "  upper-biased esimtator(a_UB):               " au; 
print "  supper-efficient estimate(based on a_UB):   " aus; 
print "";
print "  t-stat:" tstat2; 
print "";
print "  90% confidence interval for b1";
print "      " b2[2]-1.65*stdb2[2]  "<"  b2[2]  "<"   b2[2]+1.65*stdb2[2];
print "  95% confidence interval for b1";
print "      " b2[2]-1.96*stdb2[2]  "<"  b2[2]  "<"   b2[2]+1.96*stdb2[2];
print "  99% confidence interval for b1";
print "      " b2[2]-2.57*stdb2[2]  "<"  b2[2]  "<"   b2[2]+2.57*stdb2[2];
endif;

end;
